betty.extension.gramps package - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.gramps package

## Submodules

- betty.extension.gramps.config module
  - `FamilyTreeConfiguration`
    - `FamilyTreeConfiguration.__init__()`
    - `FamilyTreeConfiguration.dump()`
    - `FamilyTreeConfiguration.file_path`
    - `FamilyTreeConfiguration.load()`
    - `FamilyTreeConfiguration.update()`
  - `FamilyTreeConfigurationSequence`
    - `FamilyTreeConfigurationSequence.load_item()`
  - `GrampsConfiguration`
    - `GrampsConfiguration.__init__()`
    - `GrampsConfiguration.dump()`
    - `GrampsConfiguration.family_trees`
    - `GrampsConfiguration.load()`
    - `GrampsConfiguration.update()`

## Module contents

Integrate Betty with Gramps.

final class betty.extension.gramps.Gramps

  Bases: `ConfigurableExtension`[`GrampsConfiguration`], `Loader`

  Integrate Betty with Gramps.

  Parameters:

    - args (`typing.Any`)

    - configuration (`typing.Optional`[`typing.TypeVar`(`_ConfigurationT`, bound= `betty.config.Configuration`)])

    - kwargs (`typing.Any`)

  classmethod default_configuration() → betty.extension.gramps.config.GrampsConfiguration

    Get this extension’s default configuration.

    Return type:

      `betty.extension.gramps.config.GrampsConfiguration`

  async load() → None

    Load ancestry data.

    Return type:

      `None`

  classmethod plugin_description() → betty.locale.localizable.Localizable

    Get the human-readable long plugin description.

    Return type:

      `betty.locale.localizable.Localizable`

  classmethod plugin_id() → str

    Get the plugin ID.

    IDs are unique per plugin type: - A plugin repository MUST at most have a single plugin for any ID. - Different plugin repositories MAY each have a plugin with the same ID.

    Return type:

      `str`

  classmethod plugin_label() → betty.locale.localizable.Localizable

    Get the human-readable short plugin label.

    Return type:

      `betty.locale.localizable.Localizable`